==> activity-center-api-1.2.13.8-20170120.081851-1-sources.jar: cn/com/duiba/activity/center/api/dto/direct/DuibaActivityAppSpecifyNewDto.java <==
package cn.com.duiba.activity.center.api.dto.direct;

import java.io.Serializable;
import java.util.Date;

/**
 * Created by suyuanlong on 16/7/19.
 * 活动定向功能合并dto。
 * 背景：现在不同的活动定向，都独自走自个不同的一套逻辑。
 *      现在希望把逻辑全并起来。
 */
public class DuibaActivityAppSpecifyNewDto implements Serializable {

    private static final long serialVersionUID = -5363589927681235910L;

    public static final String ACTIVITY_GUESS="guess";

    public static final String ACTIVITY_HDTOOL="hdtool";
    public static final String ACTIVITY_MANUALLOTTERY="manuallottery";
    public static final String ACTIVITY_NGMAE="ngame";
    public static final String ACTIVITY_QUESTION="question";
    public static final String ACTIVITY_QUIZZ="quizz";
    public static final String ACTIVITY_SECKILL="seckill";
    public static final String ACTIVITY_SINGLELOTTERY="singlelottery";
    public static final String ACTIVITY_ROB = "rob";
    public static final String ACTIVITY_PLUGIN = "plugin";
    public static final String ACTIVITY_CREDIT_GAME = "creditgame";
    public static final String ACTIVITY_LITTLE_GAME = "littlegame";


    public static final String ACTIVITY_HD_TYPE_SHAKE = "shake";
    public static final String ACTIVITY_HD_TYPE_SCRATCH_CARD = "scratchCard";
    public static final String ACTIVITY_HD_TYPE_ITGER = "slotMachine";
    public static final String ACTIVITY_HD_TYPE_TURNTABLE = "turntable";
     
    public static final String ACTIVITY_HD_TYPE_ROB = "rob";
    public static final String ACTIVITY_HD_TYPE_PLUGIN = "plugin";
    
    private Long id;

    private Long appId;

    /**
     * guess：竞猜
     * hdtool：活动工具
     * manuallottery：手动开奖
     * ngame：新游戏
     * question：答题
     * quizz：测试题
     * seckill：秒杀活动
     * singlelottery：单品抽奖
     */
    private String relationType;

    private Long relationId;

    /**
     * public static final String HD_SHAKE = "shake";
     * public static final String HD_SCRATCH_CARD = "scratchCard";
     * public static final String HD_ITGER = "slotMachine";
     * public static final String HD_TURNTABLE = "turntable"
     */
    private String hdType;

    private Date gmtCreate;

    private Date gmtModified;

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public void setHdType(String hdType) {
        this.hdType = hdType;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public void setRelationId(Long relationId) {
        this.relationId = relationId;
    }

    public void setRelationType(String relationType) {
        this.relationType = relationType;
    }



    public Long getAppId() {
        return appId;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public String getHdType() {
        return hdType;
    }

    public Long getId() {
        return id;
    }

    public Long getRelationId() {
        return relationId;
    }

    public String getRelationType() {
        return relationType;
    }



}

==> activity-center-api-3.2.9-sources.jar: cn/com/duiba/activity/center/api/dto/direct/DuibaActivityAppSpecifyNewDto.java <==
package cn.com.duiba.activity.center.api.dto.direct;

import java.io.Serializable;
import java.util.Date;

/**
 * Created by suyuanlong on 16/7/19.
 * 活动定向功能合并dto。
 * 背景：现在不同的活动定向，都独自走自个不同的一套逻辑。
 *      现在希望把逻辑全并起来。
 */
public class DuibaActivityAppSpecifyNewDto implements Serializable {

    private static final long serialVersionUID = -5363589927681235910L;

    public static final String ACTIVITY_GUESS="guess";

    public static final String ACTIVITY_HDTOOL="hdtool";
    public static final String ACTIVITY_MANUALLOTTERY="manuallottery";
    public static final String ACTIVITY_NGMAE="ngame";
    public static final String ACTIVITY_QUESTION="question";
    public static final String ACTIVITY_QUIZZ="quizz";
    public static final String ACTIVITY_SECKILL="seckill";
    public static final String ACTIVITY_SINGLELOTTERY="singlelottery";
    public static final String ACTIVITY_ROB = "rob";
    public static final String ACTIVITY_PLUGIN = "plugin";
    public static final String ACTIVITY_CREDIT_GAME = "creditgame";
    public static final String ACTIVITY_LITTLE_GAME = "littlegame";


    public static final String ACTIVITY_HD_TYPE_SHAKE = "shake";
    public static final String ACTIVITY_HD_TYPE_SCRATCH_CARD = "scratchCard";
    public static final String ACTIVITY_HD_TYPE_ITGER = "slotMachine";
    public static final String ACTIVITY_HD_TYPE_TURNTABLE = "turntable";

    public static final String ACTIVITY_HD_TYPE_ROB = "rob";

    //签到体系活动
    public static final String SIGN_SYSTEM_ACTIVITY = "signSystemActivity";
    //签到体系皮肤
    public static final String SIGN_SYSTEM_ACTIVITY_SKIN = "signSystemActivitySkin";

    //图标
    public static final String APP_ICON = "appIcon";

    public static final String VISUAL_EDITOR_UNITS = "ve-units";
    public static final String VISUAL_EDITOR_TEMPLATE = "ve-template";
    /**
     * 砍价活动
     */
    public static final String BARGAIN_ACTIVITY="bargain";

    private Long id;

    private Long appId;

    /**
     * guess：竞猜
     * hdtool：活动工具
     * manuallottery：手动开奖
     * ngame：新游戏
     * question：答题
     * quizz：测试题
     * seckill：秒杀活动
     * singlelottery：单品抽奖
     */
    private String relationType;

    private Long relationId;

    /**
     * public static final String HD_SHAKE = "shake";
     * public static final String HD_SCRATCH_CARD = "scratchCard";
     * public static final String HD_ITGER = "slotMachine";
     * public static final String HD_TURNTABLE = "turntable"
     */
    private String hdType;

    private Date gmtCreate;

    private Date gmtModified;

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public void setHdType(String hdType) {
        this.hdType = hdType;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public void setRelationId(Long relationId) {
        this.relationId = relationId;
    }

    public void setRelationType(String relationType) {
        this.relationType = relationType;
    }



    public Long getAppId() {
        return appId;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public String getHdType() {
        return hdType;
    }

    public Long getId() {
        return id;
    }

    public Long getRelationId() {
        return relationId;
    }

    public String getRelationType() {
        return relationType;
    }



}
